HybridCacheStorageWriter

Struct HybridCacheStorageWriter 

pub struct HybridCacheStorageWriter<K, V, S = DefaultHasher>{ /* private fields */ }
Writer for disk cache of a hybrid cache to support more flexible write APIs.

Implementations

Source

impl<K, V, S> HybridCacheStorageWriter<K, V, S>

pub fn filter(&mut self, estimated_size: usize) -> StorageFilterResult

Check if the entry can be admitted by the admission filter of the disk cache.

The estimated_size is the estimated size of the whole entry to be inserted.

After calling filter, the writer will not be checked by the admission filter again.

pub fn force(self) -> Self

Force the disk cache to admit the writer.

Note: There is still chance that the entry is ignored because of the storage engine buffer full.

pub fn insert(self, value: V) -> Option<HybridCacheEntry<K, V, S>>

Insert the entry to the disk cache only.

pub fn insert_with_properties( self, value: V, properties: HybridCacheProperties, ) -> Option<HybridCacheEntry<K, V, S>>

Insert the entry with properties to the disk cache only.